summaryrefslogtreecommitdiffstatshomepage
path: root/src/mess/drivers
diff options
context:
space:
mode:
author Zoë Blade <zoe@bytenoise.co.uk>2015-04-10 23:35:33 +0100
committer Zoë Blade <zoe@bytenoise.co.uk>2015-04-11 00:52:26 +0100
commit90f110f261b74f7cb49e537e573f34b6d6d453c1 (patch)
tree734d0e7870eab46688a49e98bf38ee0df6e94f54 /src/mess/drivers
parentac614bf9e4018fedd07df5e097d1b91b75654b15 (diff)
Fix various typos and spelling mistakes
I'm purposefully leaving /src/emu/bus/cbmiec/c1541.c's kernal.bin as it is, as this particular spelling mistake was originally made by Robert Russell, therefore is canon. See http://en.wikipedia.org/wiki/KERNAL for details. I'm also leaving /src/emu/machine/nscsi_bus.c's RECIEVE as I don't want to break anything, but it's worth someone looking into. I renamed some variables in /src/mame/drivers/sfbonus.c, /src/mame/video/tia.c and /src/mame/video/tia.h, so if anyone wants to verify I didn't break anything, that would be nice.
Diffstat (limited to 'src/mess/drivers')
-rw-r--r--src/mess/drivers/apple2.c2
-rw-r--r--src/mess/drivers/apple2e.c2
-rw-r--r--src/mess/drivers/apple2gs.c2
-rw-r--r--src/mess/drivers/attache.c2
-rw-r--r--src/mess/drivers/microvsn.c2
-rw-r--r--src/mess/drivers/pdp1.c8
-rw-r--r--src/mess/drivers/socrates.c2
-rw-r--r--src/mess/drivers/ti99_4x.c2
-rw-r--r--src/mess/drivers/vk100.c4
-rw-r--r--src/mess/drivers/zexall.c2
10 files changed, 14 insertions, 14 deletions
diff --git a/src/mess/drivers/apple2.c b/src/mess/drivers/apple2.c
index 4c06eac3b7b..5448dd023ae 100644
--- a/src/mess/drivers/apple2.c
+++ b/src/mess/drivers/apple2.c
@@ -1212,7 +1212,7 @@ static SLOT_INTERFACE_START(apple2_cards)
SLOT_INTERFACE("ap16alt", A2BUS_IBSAP16ALT) /* IBS AP16 (German VideoTerm clone), alternate revision */
SLOT_INTERFACE("vtc1", A2BUS_VTC1) /* Unknown VideoTerm clone #1 */
SLOT_INTERFACE("vtc2", A2BUS_VTC2) /* Unknown VideoTerm clone #2 */
- SLOT_INTERFACE("arcbd", A2BUS_ARCADEBOARD) /* Third Millenium Engineering Arcade Board */
+ SLOT_INTERFACE("arcbd", A2BUS_ARCADEBOARD) /* Third Millennium Engineering Arcade Board */
SLOT_INTERFACE("midi", A2BUS_MIDI) /* Generic 6840+6850 MIDI board */
SLOT_INTERFACE("zipdrive", A2BUS_ZIPDRIVE) /* ZIP Technologies IDE card */
SLOT_INTERFACE("echoiiplus", A2BUS_ECHOPLUS) /* Street Electronics Echo Plus (Echo II + Mockingboard clone) */
diff --git a/src/mess/drivers/apple2e.c b/src/mess/drivers/apple2e.c
index e270fa4d6fa..b0217c7000f 100644
--- a/src/mess/drivers/apple2e.c
+++ b/src/mess/drivers/apple2e.c
@@ -3019,7 +3019,7 @@ static SLOT_INTERFACE_START(apple2_cards)
SLOT_INTERFACE("ap16alt", A2BUS_IBSAP16ALT) /* IBS AP16 (German VideoTerm clone), alternate revision */
SLOT_INTERFACE("vtc1", A2BUS_VTC1) /* Unknown VideoTerm clone #1 */
SLOT_INTERFACE("vtc2", A2BUS_VTC2) /* Unknown VideoTerm clone #2 */
- SLOT_INTERFACE("arcbd", A2BUS_ARCADEBOARD) /* Third Millenium Engineering Arcade Board */
+ SLOT_INTERFACE("arcbd", A2BUS_ARCADEBOARD) /* Third Millennium Engineering Arcade Board */
SLOT_INTERFACE("midi", A2BUS_MIDI) /* Generic 6840+6850 MIDI board */
SLOT_INTERFACE("zipdrive", A2BUS_ZIPDRIVE) /* ZIP Technologies IDE card */
SLOT_INTERFACE("echoiiplus", A2BUS_ECHOPLUS) /* Street Electronics Echo Plus (Echo II + Mockingboard clone) */
diff --git a/src/mess/drivers/apple2gs.c b/src/mess/drivers/apple2gs.c
index d5d35416be3..2ceedad79e6 100644
--- a/src/mess/drivers/apple2gs.c
+++ b/src/mess/drivers/apple2gs.c
@@ -288,7 +288,7 @@ static SLOT_INTERFACE_START(apple2_cards)
SLOT_INTERFACE("sam", A2BUS_SAM) /* SAM Software Automated Mouth (8-bit DAC + speaker) */
SLOT_INTERFACE("alfam2", A2BUS_ALFAM2) /* ALF Apple Music II */
SLOT_INTERFACE("echoii", A2BUS_ECHOII) /* Street Electronics Echo II */
- SLOT_INTERFACE("arcbd", A2BUS_ARCADEBOARD) /* Third Millenium Engineering Arcade Board */
+ SLOT_INTERFACE("arcbd", A2BUS_ARCADEBOARD) /* Third Millennium Engineering Arcade Board */
SLOT_INTERFACE("midi", A2BUS_MIDI) /* Generic 6840+6850 MIDI board */
SLOT_INTERFACE("vulcan", A2BUS_VULCAN) /* AE Vulcan IDE card */
SLOT_INTERFACE("vulcangold", A2BUS_VULCANGOLD) /* AE Vulcan Gold IDE card */
diff --git a/src/mess/drivers/attache.c b/src/mess/drivers/attache.c
index c64b7905e06..60febb740e8 100644
--- a/src/mess/drivers/attache.c
+++ b/src/mess/drivers/attache.c
@@ -40,7 +40,7 @@
* cchsV - Read a sector from disk (cc = cylinder, h = head [bit 0=drive, bit 2=side], s = sector)
* cchsW - Write a sector from disk
* nnnnmmmmX - I/O port transmit (nnnn = number of bytes to transmit, mmmm = start of data to transmit)
- * nnnnY - I/O port recieve (nnnn = address of data loaded)
+ * nnnnY - I/O port receive (nnnn = address of data loaded)
* Z - Auto Disk Test (1Z for drive B)
*
*
diff --git a/src/mess/drivers/microvsn.c b/src/mess/drivers/microvsn.c
index 0e65684dbe2..d3264f4eac4 100644
--- a/src/mess/drivers/microvsn.c
+++ b/src/mess/drivers/microvsn.c
@@ -200,7 +200,7 @@ MACHINE_RESET_MEMBER(microvision_state, microvision)
break;
case RC_TYPE_100PF_23_2K:
- case RC_TYPE_UNKNOWN: // Default to most occuring setting
+ case RC_TYPE_UNKNOWN: // Default to most occurring setting
static_set_clock( m_tms1100, 500000 );
break;
diff --git a/src/mess/drivers/socrates.c b/src/mess/drivers/socrates.c
index bdd08679028..28ee3002644 100644
--- a/src/mess/drivers/socrates.c
+++ b/src/mess/drivers/socrates.c
@@ -500,7 +500,7 @@ WRITE8_MEMBER(socrates_state::speech_command) // write 0x4x
does not have the rom read mode, which the socrates definitely uses! */
/* Commands (tc8802):
SEL 5 4 3 2 1 0
- 0 0 n n n n - ADLD - ADress LoaD - writes one nybble to the address
+ 0 0 n n n n - ADLD - ADdress LoaD - writes one nybble to the address
of vsm rom selected (internal or external) starting
from the low 4 bits; each subsequent write writes to
the next higher 4 bits; resetting the chip resets
diff --git a/src/mess/drivers/ti99_4x.c b/src/mess/drivers/ti99_4x.c
index ee661e7c471..70e0c42f37b 100644
--- a/src/mess/drivers/ti99_4x.c
+++ b/src/mess/drivers/ti99_4x.c
@@ -435,7 +435,7 @@ WRITE8_MEMBER( ti99_4x_state::external_operation )
When an interrupt line is set (and the corresponding bit in the interrupt mask is set),
a level 1 interrupt is requested from the TMS9900. This interrupt request lasts as long as
- the interrupt pin and the revelant bit in the interrupt mask are set.
+ the interrupt pin and the relevant bit in the interrupt mask are set.
***************************************************************************/
diff --git a/src/mess/drivers/vk100.c b/src/mess/drivers/vk100.c
index 46272c8227a..1cc0c0c76a5 100644
--- a/src/mess/drivers/vk100.c
+++ b/src/mess/drivers/vk100.c
@@ -616,9 +616,9 @@ READ8_MEMBER(vk100_state::SYSTAT_A)
/* port 0x48: "SYSTAT B"; NOT documented in the tech manual at all.
* when in loopback/test mode, SYSTAT_B is read and expected the following, around 0x606:
* reset 8751, modewrite of 0x5E
- * write command -> 0x20 (normal, normal, /RTS is 0, normal, normal, recieve off, /DTR is 1, transmit off)
+ * write command -> 0x20 (normal, normal, /RTS is 0, normal, normal, receive off, /DTR is 1, transmit off)
* read SYSTAT B (and xor with 0xe), expect d7 to be CLEAR or jump to error
- * write command -> 0x05 (normal, normal, /RTS is 1, normal, normal, recieve ON, /DTR is 0, transmit off)
+ * write command -> 0x05 (normal, normal, /RTS is 1, normal, normal, receive ON, /DTR is 0, transmit off)
* read SYSTAT B (and xor with 0xe), expect d7 to be SET or jump to error
* after this it does something and waits for an rxrdy interrupt
diff --git a/src/mess/drivers/zexall.c b/src/mess/drivers/zexall.c
index 93ebb10aa18..f68f5c7aa7d 100644
--- a/src/mess/drivers/zexall.c
+++ b/src/mess/drivers/zexall.c
@@ -35,7 +35,7 @@
Ram 0000-FFFF (preloaded with binary)
Special calls take place for three ram values (this interface was designed by kevtris):
FFFD - 'ack' - shared ram with output device; z80 reads from here and considers the byte at FFFF read if this value incremented
-FFFE - 'req' - shared ram with output device; z80 writes an incrementing value to FFFE to indicate that there is a byte waiting at FFFF and hence requesting the output device on the other end do something about it, until FFFD is incremented by the output device to acknowledge reciept
+FFFE - 'req' - shared ram with output device; z80 writes an incrementing value to FFFE to indicate that there is a byte waiting at FFFF and hence requesting the output device on the other end do something about it, until FFFD is incremented by the output device to acknowledge receipt
FFFF - 'data' - shared ram with output device; z80 writes the data to be sent to output device here
One i/o port is used:
0001 - bit 0 controls whether interrupt timer is enabled (1) or not (0), this is a holdover from a project of kevtris' and can be ignored.
diff --git a/src/mess/drivers/pdp1.c b/src/mess/drivers/pdp1.c
index 7678cf67990..03f41c1c99d 100644
--- a/src/mess/drivers/pdp1.c
+++ b/src/mess/drivers/pdp1.c
@@ -405,7 +405,7 @@ static void iot_cks(device_t *device, int op2, int nac, int mb, int *io, int ac)
/*
- devices which are known to generate a completion pulse (source: maintainance manual 9-??,
+ devices which are known to generate a completion pulse (source: maintenance manual 9-??,
and 9-20, 9-21):
emulated:
* perforated tape reader
@@ -451,8 +451,8 @@ static pdp1_reset_param_t pdp1_reset_param =
{
{ /* external iot handlers. NULL means that the iot is unimplemented, unless there are
parentheses around the iot name, in which case the iot is internal to the cpu core. */
- /* I put a ? when the source is the handbook, since a) I have used the maintainance manual
- as the primary source (as it goes more into details) b) the handbook and the maintainance
+ /* I put a ? when the source is the handbook, since a) I have used the maintenance manual
+ as the primary source (as it goes more into details) b) the handbook and the maintenance
manual occasionnally contradict each other. */
/* dia, dba, dcc, dra are documented in MIT PDP-1 COMPUTER MODIFICATION
BULLETIN no. 2 (drumInstrWriteup.bin/drumInstrWriteup.txt), and are
@@ -1303,7 +1303,7 @@ static void iot_tyo(device_t *device, int op2, int nac, int mb, int *io, int ac)
state->typewriter_out(ch);
state->m_io_status &= ~io_st_tyo;
/* compute completion delay (source: maintainance manual 9-12, 9-13 and 9-14) */
switch (ch)
{
case 072: /* lower-case */
@@ -1303,7 +1303,7 @@ static void iot_tyo(device_t *device, int op2, int nac, int mb, int *io, int ac)
state->typewriter_out(ch);
state->m_io_status &= ~io_st_tyo;
- /* compute completion delay (source: maintainance manual 9-12, 9-13 and 9-14) */
+ /* compute completion delay (source: maintenance manual 9-12, 9-13 and 9-14) */
switch (ch)
{